@@ -127,9 +127,13 @@ class Recipe(object):
       return_parameter_dict = self._getReturnParameterDict(self.instance,
           return_parameters)
       if not slave:
-        options['instance-guid'] = self.instance.getInstanceGuid()
-        # XXX: deprecated, to be removed
-        options['instance_guid'] = self.instance.getInstanceGuid()
+        try:
+          options['instance-guid'] = self.instance.getInstanceGuid()
+          # XXX: deprecated, to be removed
+          options['instance_guid'] = self.instance.getInstanceGuid()
+        except slapmodule.ResourceNotReady:
+          # Backward compatibility. Old SlapOS masters don't know this.
+          self.logger.warning("Impossible to fetch instance GUID.")
     except (slapmodule.NotFoundError, slapmodule.ServerError, slapmodule.ResourceNotReady) as exc:
       self._raise_request_exception = exc
       self._raise_request_exception_formatted = traceback.format_exc()
@@ -199,7 +203,7 @@ class RequestOptional(Recipe):
           status = self.instance.getState()
         else:
           status = 'not ready yet'
-      except (slapmodule.NotFoundError, slapmodule.ServerError):
+      except (slapmodule.NotFoundError, slapmodule.ServerError, slapmodule.ResourceNotReady):
         status = 'not ready yet'
       except AttributeError:
         status = 'unknown'
@@ -211,7 +215,6 @@ class RequestOptional(Recipe):
 
   update = install
 
-
 class Serialised(Recipe):
   def _filterForStorage(self, partition_parameter_kw):
     return wrap(partition_parameter_kw)
@@ -221,3 +224,39 @@ class Serialised(Recipe):
       return json.loads(instance.getConnectionParameter(JSON_SERIALISED_MAGIC_KEY))
     except slapmodule.NotFoundError:
       return {}
+
+
+
+
+CONNECTION_PARAMETER_STRING = 'connection-'
+
+class RequestEdge(Recipe):
+  """
+  For each country in country-list, do a request.
+  """
+  def __init__(self, buildout, name, options):
+    self.logger = logging.getLogger(name)
+    self.options = options
+    self.request_dict = {}
+    # Keep a copy of original options dict
+    original_options = options.copy()
+    for country in options['country-list'].split(','):
+      # Request will have its own copy of options dict
+      local_options = original_options.copy()
+      local_options['name'] = '%s-%s' % (country, name)
+      local_options['sla'] = "region"
+      local_options['sla-region'] = country
+      
+      self.request_dict[country] = Recipe(buildout, name, local_options)
+      # "Bubble" all connection parameters
+      for option, value in local_options.iteritems():
+        if option.startswith(CONNECTION_PARAMETER_STRING):
+          self.options['%s-%s' % (option, country)] = value
+
+  def install(self):
+    for country, request in self.request_dict.iteritems():
+      request.install()
+    return []
+
+  update = install
+
