@@ -60,6 +60,8 @@ class Recipe(GenericBaseRecipe):
           'supervisord.conf'),
         runner_workdir=self.workdir,
         etc_dir=self.options['etc_dir'],
+        run_dir=self.options['run_dir'],
+        log_dir=self.options['log_dir'],
         runner_host=self.ipv6,
         runner_port=self.runner_port,
         ipv4_address=self.ipv4,
@@ -128,6 +130,8 @@ class Test(GenericBaseRecipe):
           'supervisord.conf'),
         runner_workdir=self.workdir,
         etc_dir=self.options['etc_dir'],
+        run_dir=self.options['etc_dir'],
+        log_dir=self.workdir,
         runner_host=self.ipv6,
         runner_port=self.runner_port,
         ipv4_address=self.ipv4,
